@@ -35,13 +35,13 @@ public:
         : QWebEngineUrlSchemeHandler(parent)
     {
     }
-    void requestStarted(QWebEngineUrlRequestJob *job) {
+    void requestStarted(QWebEngineUrlRequestJob *job) override {
         job->fail(QWebEngineUrlRequestJob::UrlInvalid);
         const QString word = job->requestUrl().path();
         emit wordClicked(word);
    }
 
-signals:
+Q_SIGNALS:
     void wordClicked(const QString &word);
 };
 
@@ -60,7 +60,7 @@ DictObject::DictObject(QObject *parent)
 
 void DictObject::lookup(const QString &word)
 {
-    const QString newSource = m_selectedDict + ':' + word;
+    const QString newSource = m_selectedDict + QLatin1Char(':') + word;
 
     if (!m_source.isEmpty()) {
         m_dataEngine->disconnectSource(m_source, this);
